<?php

namespace Superrobota\Announcement\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Superrobota\Announcement\Http\Requests\JobOffertRequest;
use Superrobota\Announcement\Interfaces\JobOffertRepositoryInterface;
use Superrobota\Announcement\Models\JobOffert;

/**
 * Resource controller class for job_offert.
 */
class JobOffertResourceController extends BaseController
{

    /**
     * Initialize job_offert resource controller.
     *
     * @param type JobOffertRepositoryInterface $job_offert
     *
     * @return null
     */
    public function __construct(JobOffertRepositoryInterface $job_offert)
    {
        parent::__construct();
        $this->repository = $job_offert;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Superrobota\Announcement\Repositories\Criteria\JobOffertResourceCriteria::class);
    }

    /**
     * Display a list of job_offert.
     *
     * @return Response
     */
    public function index(JobOffertRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Superrobota\Announcement\Repositories\Presenter\JobOffertPresenter::class)
                ->$function();
        }

        $job_offerts = $this->repository->paginate();

        return $this->response->title(trans('announcement::job_offert.names'))
            ->view('announcement::job_offert.index', true)
            ->data(compact('job_offerts'))
            ->output();
    }

    /**
     * Display job_offert.
     *
     * @param Request $request
     * @param Model   $job_offert
     *
     * @return Response
     */
    public function show(JobOffertRequest $request, JobOffert $job_offert)
    {

        if ($job_offert->exists) {
            $view = 'announcement::job_offert.show';
        } else {
            $view = 'announcement::job_offert.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('announcement::job_offert.name'))
            ->data(compact('job_offert'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new job_offert.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(JobOffertRequest $request)
    {

        $job_offert = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('announcement::job_offert.name')) 
            ->view('announcement::job_offert.create', true) 
            ->data(compact('job_offert'))
            ->output();
    }

    /**
     * Create new job_offert.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(JobOffertRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $job_offert                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('announcement::job_offert.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('announcement/job_offert/' . $job_offert->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/announcement/job_offert'))
                ->redirect();
        }

    }

    /**
     * Show job_offert for editing.
     *
     * @param Request $request
     * @param Model   $job_offert
     *
     * @return Response
     */
    public function edit(JobOffertRequest $request, JobOffert $job_offert)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('announcement::job_offert.name'))
            ->view('announcement::job_offert.edit', true)
            ->data(compact('job_offert'))
            ->output();
    }

    /**
     * Update the job_offert.
     *
     * @param Request $request
     * @param Model   $job_offert
     *
     * @return Response
     */
    public function update(JobOffertRequest $request, JobOffert $job_offert)
    {
        try {
            $attributes = $request->all();

            $job_offert->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('announcement::job_offert.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('announcement/job_offert/' . $job_offert->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('announcement/job_offert/' . $job_offert->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the job_offert.
     *
     * @param Model   $job_offert
     *
     * @return Response
     */
    public function destroy(JobOffertRequest $request, JobOffert $job_offert)
    {
        try {

            $job_offert->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('announcement::job_offert.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('announcement/job_offert/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('announcement/job_offert/' . $job_offert->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple job_offert.
     *
     * @param Model   $job_offert
     *
     * @return Response
     */
    public function delete(JobOffertRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('announcement::job_offert.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('announcement/job_offert'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/announcement/job_offert'))
                ->redirect();
        }

    }

    /**
     * Restore deleted job_offerts.
     *
     * @param Model   $job_offert
     *
     * @return Response
     */
    public function restore(JobOffertRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('announcement::job_offert.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/announcement/job_offert'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/announcement/job_offert/'))
                ->redirect();
        }

    }

}
