<?php

namespace Superrobota\Announcement\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Superrobota\Announcement\Http\Requests\RentalOfferRequest;
use Superrobota\Announcement\Interfaces\RentalOfferRepositoryInterface;
use Superrobota\Announcement\Models\RentalOffer;

/**
 * Resource controller class for rental_offer.
 */
class RentalOfferResourceController extends BaseController
{

    /**
     * Initialize rental_offer resource controller.
     *
     * @param type RentalOfferRepositoryInterface $rental_offer
     *
     * @return null
     */
    public function __construct(RentalOfferRepositoryInterface $rental_offer)
    {
        parent::__construct();
        $this->repository = $rental_offer;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Superrobota\Announcement\Repositories\Criteria\RentalOfferResourceCriteria::class);
    }

    /**
     * Display a list of rental_offer.
     *
     * @return Response
     */
    public function index(RentalOfferRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Superrobota\Announcement\Repositories\Presenter\RentalOfferPresenter::class)
                ->$function();
        }

        $rental_offers = $this->repository->paginate();

        return $this->response->title(trans('announcement::rental_offer.names'))
            ->view('announcement::rental_offer.index', true)
            ->data(compact('rental_offers'))
            ->output();
    }

    /**
     * Display rental_offer.
     *
     * @param Request $request
     * @param Model   $rental_offer
     *
     * @return Response
     */
    public function show(RentalOfferRequest $request, RentalOffer $rental_offer)
    {

        if ($rental_offer->exists) {
            $view = 'announcement::rental_offer.show';
        } else {
            $view = 'announcement::rental_offer.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('announcement::rental_offer.name'))
            ->data(compact('rental_offer'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new rental_offer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(RentalOfferRequest $request)
    {

        $rental_offer = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('announcement::rental_offer.name')) 
            ->view('announcement::rental_offer.create', true) 
            ->data(compact('rental_offer'))
            ->output();
    }

    /**
     * Create new rental_offer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RentalOfferRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $rental_offer                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('announcement::rental_offer.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('announcement/rental_offer/' . $rental_offer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/announcement/rental_offer'))
                ->redirect();
        }

    }

    /**
     * Show rental_offer for editing.
     *
     * @param Request $request
     * @param Model   $rental_offer
     *
     * @return Response
     */
    public function edit(RentalOfferRequest $request, RentalOffer $rental_offer)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('announcement::rental_offer.name'))
            ->view('announcement::rental_offer.edit', true)
            ->data(compact('rental_offer'))
            ->output();
    }

    /**
     * Update the rental_offer.
     *
     * @param Request $request
     * @param Model   $rental_offer
     *
     * @return Response
     */
    public function update(RentalOfferRequest $request, RentalOffer $rental_offer)
    {
        try {
            $attributes = $request->all();

            $rental_offer->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('announcement::rental_offer.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('announcement/rental_offer/' . $rental_offer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('announcement/rental_offer/' . $rental_offer->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the rental_offer.
     *
     * @param Model   $rental_offer
     *
     * @return Response
     */
    public function destroy(RentalOfferRequest $request, RentalOffer $rental_offer)
    {
        try {

            $rental_offer->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('announcement::rental_offer.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('announcement/rental_offer/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('announcement/rental_offer/' . $rental_offer->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple rental_offer.
     *
     * @param Model   $rental_offer
     *
     * @return Response
     */
    public function delete(RentalOfferRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('announcement::rental_offer.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('announcement/rental_offer'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/announcement/rental_offer'))
                ->redirect();
        }

    }

    /**
     * Restore deleted rental_offers.
     *
     * @param Model   $rental_offer
     *
     * @return Response
     */
    public function restore(RentalOfferRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('announcement::rental_offer.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/announcement/rental_offer'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/announcement/rental_offer/'))
                ->redirect();
        }

    }

}
