<?php

namespace Superrobota\Announcement\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Superrobota\Announcement\Http\Requests\TrainingOffertRequest;
use Superrobota\Announcement\Interfaces\TrainingOffertRepositoryInterface;
use Superrobota\Announcement\Models\TrainingOffert;

/**
 * Resource controller class for training_offert.
 */
class TrainingOffertResourceController extends BaseController
{

    /**
     * Initialize training_offert resource controller.
     *
     * @param type TrainingOffertRepositoryInterface $training_offert
     *
     * @return null
     */
    public function __construct(TrainingOffertRepositoryInterface $training_offert)
    {
        parent::__construct();
        $this->repository = $training_offert;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Superrobota\Announcement\Repositories\Criteria\TrainingOffertResourceCriteria::class);
    }

    /**
     * Display a list of training_offert.
     *
     * @return Response
     */
    public function index(TrainingOffertRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Superrobota\Announcement\Repositories\Presenter\TrainingOffertPresenter::class)
                ->$function();
        }

        $training_offerts = $this->repository->paginate();

        return $this->response->title(trans('announcement::training_offert.names'))
            ->view('announcement::training_offert.index', true)
            ->data(compact('training_offerts'))
            ->output();
    }

    /**
     * Display training_offert.
     *
     * @param Request $request
     * @param Model   $training_offert
     *
     * @return Response
     */
    public function show(TrainingOffertRequest $request, TrainingOffert $training_offert)
    {

        if ($training_offert->exists) {
            $view = 'announcement::training_offert.show';
        } else {
            $view = 'announcement::training_offert.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('announcement::training_offert.name'))
            ->data(compact('training_offert'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new training_offert.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TrainingOffertRequest $request)
    {

        $training_offert = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('announcement::training_offert.name')) 
            ->view('announcement::training_offert.create', true) 
            ->data(compact('training_offert'))
            ->output();
    }

    /**
     * Create new training_offert.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TrainingOffertRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $training_offert                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('announcement::training_offert.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('announcement/training_offert/' . $training_offert->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/announcement/training_offert'))
                ->redirect();
        }

    }

    /**
     * Show training_offert for editing.
     *
     * @param Request $request
     * @param Model   $training_offert
     *
     * @return Response
     */
    public function edit(TrainingOffertRequest $request, TrainingOffert $training_offert)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('announcement::training_offert.name'))
            ->view('announcement::training_offert.edit', true)
            ->data(compact('training_offert'))
            ->output();
    }

    /**
     * Update the training_offert.
     *
     * @param Request $request
     * @param Model   $training_offert
     *
     * @return Response
     */
    public function update(TrainingOffertRequest $request, TrainingOffert $training_offert)
    {
        try {
            $attributes = $request->all();

            $training_offert->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('announcement::training_offert.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('announcement/training_offert/' . $training_offert->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('announcement/training_offert/' . $training_offert->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the training_offert.
     *
     * @param Model   $training_offert
     *
     * @return Response
     */
    public function destroy(TrainingOffertRequest $request, TrainingOffert $training_offert)
    {
        try {

            $training_offert->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('announcement::training_offert.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('announcement/training_offert/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('announcement/training_offert/' . $training_offert->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple training_offert.
     *
     * @param Model   $training_offert
     *
     * @return Response
     */
    public function delete(TrainingOffertRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('announcement::training_offert.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('announcement/training_offert'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/announcement/training_offert'))
                ->redirect();
        }

    }

    /**
     * Restore deleted training_offerts.
     *
     * @param Model   $training_offert
     *
     * @return Response
     */
    public function restore(TrainingOffertRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('announcement::training_offert.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/announcement/training_offert'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/announcement/training_offert/'))
                ->redirect();
        }

    }

}
